@@ -41,15 +41,37 @@
 #include "cairo-dock-menu.h"
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-X-utilities.h"
+#include "cairo-dock-surface-factory.h"
+#include "cairo-dock-renderer-manager.h"
 #include "cairo-dock-desklet.h"
 
 extern CairoDock *g_pMainDock;
 extern int g_iScreenWidth[2], g_iScreenHeight[2];
 extern gchar *g_cConfFile;
 extern int g_iDockRadius;
-extern double g_fDeskletColor[4];
-extern double g_fDeskletColorInside[4];
 extern gboolean g_bSticky;
+extern gchar *g_cDeskletDecorationsName;
+
+#define CAIRO_DOCK_DESKLET_BUTTONS_SIZE 16
+static cairo_surface_t *pRotateButtonSurface = NULL;
+static cairo_surface_t *pRetachButtonSurface = NULL;
+
+void cairo_dock_load_desklet_buttons (cairo_t *pSourceContext)
+{
+	if (pRotateButtonSurface == NULL)
+	{
+		gchar *cRotateButtonPath = g_strdup_printf ("%s/%s", CAIRO_DOCK_SHARE_DATA_DIR, "rotate-desklet.svg");
+		pRotateButtonSurface = cairo_dock_create_surface_for_icon (cRotateButtonPath, pSourceContext, CAIRO_DOCK_DESKLET_BUTTONS_SIZE, CAIRO_DOCK_DESKLET_BUTTONS_SIZE);
+		g_free (cRotateButtonPath);
+	}
+	
+	if (pRetachButtonSurface == NULL)
+	{
+		gchar *cRetachButtonPath = g_strdup_printf ("%s/%s", CAIRO_DOCK_SHARE_DATA_DIR, "retach-desklet.svg");
+		pRetachButtonSurface = cairo_dock_create_surface_for_icon (cRetachButtonPath, pSourceContext, CAIRO_DOCK_DESKLET_BUTTONS_SIZE, CAIRO_DOCK_DESKLET_BUTTONS_SIZE);
+		g_free (cRetachButtonPath);
+	}
+}
 
 static gboolean on_expose_desklet(GtkWidget *pWidget,
 	GdkEventExpose *pExpose,
@@ -62,23 +84,23 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 	
 	cairo_t *pCairoContext;
 	//set the color
-	double fColor[4];
+	double fColor[4] = {1., 1., 1., 0.};
 	int i;
-	for (i = 0; i < 4; i ++)
-	{
-		fColor[i] = (g_fDeskletColorInside[i] * pDesklet->iGradationCount + g_fDeskletColor[i] * (CD_NB_ITER_FOR_GRADUATION - pDesklet->iGradationCount)) / CD_NB_ITER_FOR_GRADUATION;
-	}
-	if (gtk_window_is_active (GTK_WINDOW (pDesklet->pWidget)))
-		fColor[3] = MIN (1., fColor[3] * 1.25);
 	
+	if (gtk_window_is_active (GTK_WINDOW (pDesklet->pWidget)))
+		fColor[3] = 1.;
+	else
+		fColor[3] = 1.*pDesklet->iGradationCount / CD_NB_ITER_FOR_GRADUATION;
 	
 	gboolean bRenderOptimized = (pExpose->area.x > 0 || pExpose->area.y > 0);
 	if (bRenderOptimized)
 	{
+		g_print ("Using optimized render\n");
 		pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDesklet), &pExpose->area, fColor);
 	}
 	else
 	{
+		//cd_debug ("Using normal render");
 		pCairoContext = cairo_dock_create_drawing_context (CAIRO_CONTAINER (pDesklet));
 		
 		if (pDesklet->fZoom != 1)
@@ -99,27 +121,73 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 		pDesklet->iDesiredWidth = 0;
 		pDesklet->iDesiredHeight = 0;
 		
-		
 		if (fColor[3] != 0)
 		{
-			cairo_save (pCairoContext);
-			cairo_set_source_rgba (pCairoContext, fColor[0], fColor[1], fColor[2], fColor[3]);
-			cairo_set_line_width (pCairoContext, g_iDockRadius);
-			cairo_set_line_join (pCairoContext, CAIRO_LINE_JOIN_ROUND);
-			//draw a rounded square
-			w = pDesklet->iWidth;
-			h = pDesklet->iHeight;
-			cairo_move_to (pCairoContext, .5*g_iDockRadius, .5*g_iDockRadius);
-			cairo_rel_line_to (pCairoContext, w - (g_iDockRadius), 0);
-			cairo_rel_line_to (pCairoContext, 0, h - (g_iDockRadius));
-			cairo_rel_line_to (pCairoContext, -(w - (g_iDockRadius)) , 0);
-			cairo_close_path (pCairoContext);
-			cairo_stroke (pCairoContext);
+			cairo_pattern_t *pPattern = cairo_pattern_create_radial (.5*pDesklet->iWidth,
+				.5*pDesklet->iHeight,
+				0.,
+				.5*pDesklet->iWidth,
+				.5*pDesklet->iHeight,
+				.5*MIN (pDesklet->iWidth, pDesklet->iHeight));
+			 cairo_pattern_set_extend (pPattern, CAIRO_EXTEND_NONE);
 			
-			cairo_rectangle(pCairoContext, g_iDockRadius, g_iDockRadius, (w - 2*g_iDockRadius), (h - 2*g_iDockRadius));
-			cairo_fill(pCairoContext);
-			cairo_restore (pCairoContext);  // retour au debut.
+			cairo_pattern_add_color_stop_rgba   (pPattern,
+				0.,
+				fColor[0], fColor[1], fColor[2], fColor[3]);
+			cairo_pattern_add_color_stop_rgba   (pPattern,
+				1.,
+				fColor[0], fColor[1], fColor[2], 0.);
+			cairo_set_source (pCairoContext, pPattern);
+			cairo_paint (pCairoContext);
+			cairo_pattern_destroy (pPattern);
 		}
+		
+		cairo_save (pCairoContext);
+		
+		if (pDesklet->fRotation != 0)
+		{
+			double alpha = atan2 (pDesklet->iHeight, pDesklet->iWidth);
+			double theta = fabs (pDesklet->fRotation);
+			if (theta > G_PI/2)
+				theta -= G_PI/2;
+			double fZoomX, fZoomY;
+			double d = .5 * sqrt (pDesklet->iWidth * pDesklet->iWidth + pDesklet->iHeight * pDesklet->iHeight);
+			fZoomX = fabs (.5 * pDesklet->iWidth / (d * sin (alpha + theta)));
+			fZoomY = fabs (.5 * pDesklet->iHeight / (d * cos (alpha - theta)));
+			//g_print ("d = %.2f ; alpha = %.2f ; zoom : %.2fx%.2f\n", d, alpha/G_PI*180., fZoomX, fZoomY);
+			
+			cairo_translate (pCairoContext,
+				.5*pDesklet->iWidth,
+				.5*pDesklet->iHeight);
+			
+			cairo_rotate (pCairoContext, pDesklet->fRotation);
+			
+			cairo_translate (pCairoContext,
+				-.5*pDesklet->iWidth * fZoomX,
+				-.5*pDesklet->iHeight * fZoomY);
+			cairo_scale (pCairoContext, fZoomX, fZoomY);
+		}
+	}
+	
+	cairo_save (pCairoContext);
+	if (pDesklet->pBackGroundSurface != NULL && pDesklet->fBackGroundAlpha != 0)
+	{
+		cairo_set_source_surface (pCairoContext,
+			pDesklet->pBackGroundSurface,
+			0.,
+			0.);
+		if (pDesklet->fBackGroundAlpha == 1)
+			cairo_paint (pCairoContext);
+		else
+			cairo_paint_with_alpha (pCairoContext, pDesklet->fBackGroundAlpha);
+	}
+	
+	if (pDesklet->iLeftSurfaceOffset != 0 || pDesklet->iTopSurfaceOffset != 0 || pDesklet->iRightSurfaceOffset != 0 || pDesklet->iBottomSurfaceOffset != 0)
+	{
+		cairo_translate (pCairoContext, pDesklet->iLeftSurfaceOffset, pDesklet->iTopSurfaceOffset);
+		cairo_scale (pCairoContext,
+			1. - 1.*(pDesklet->iLeftSurfaceOffset + pDesklet->iRightSurfaceOffset) / pDesklet->iWidth,
+			1. - 1.*(pDesklet->iTopSurfaceOffset + pDesklet->iBottomSurfaceOffset) / pDesklet->iHeight);
 	}
 	
 	if (pDesklet->pRenderer != NULL)  // un moteur de rendu specifique a ete fourni.
@@ -128,6 +196,35 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 			pDesklet->pRenderer->render (pCairoContext, pDesklet, bRenderOptimized);
 	}
 	
+	cairo_restore (pCairoContext);
+	if (pDesklet->pForeGroundSurface != NULL && pDesklet->fForeGroundAlpha != 0)
+	{
+		cairo_set_source_surface (pCairoContext,
+			pDesklet->pForeGroundSurface,
+			0.,
+			0.);
+		if (pDesklet->fForeGroundAlpha == 1)
+			cairo_paint (pCairoContext);
+		else
+			cairo_paint_with_alpha (pCairoContext, pDesklet->fForeGroundAlpha);
+	}
+	
+	if (pDesklet->bInside || pDesklet->rotating)
+	{
+		if (! pDesklet->rotating)
+			cairo_restore (pCairoContext);
+		if (pRotateButtonSurface != NULL)
+		{
+			cairo_set_source_surface (pCairoContext, pRotateButtonSurface, 0., 0.);
+			cairo_paint (pCairoContext);
+		}
+		if (pRetachButtonSurface != NULL)
+		{
+			cairo_set_source_surface (pCairoContext, pRetachButtonSurface, pDesklet->iWidth - CAIRO_DOCK_DESKLET_BUTTONS_SIZE, 0.);
+			cairo_paint (pCairoContext);
+		}
+	}
+
 	cairo_destroy (pCairoContext);
 	return FALSE;
 }
@@ -135,24 +232,32 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 
 static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 {
+	g_print ("%s (%dx%d ; %dx%d)\n", __func__, pDesklet->iWidth, pDesklet->iHeight, pDesklet->iDesiredWidth, pDesklet->iDesiredHeight);
 	if (pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL)
 		cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
 			G_TYPE_INT, "Desklet", "width", pDesklet->iWidth,
 			G_TYPE_INT, "Desklet", "height", pDesklet->iHeight,
 			G_TYPE_INVALID);
 	pDesklet->iSidWriteSize = 0;
-	if (pDesklet->pIcon != NULL)
+	pDesklet->iKnownWidth = pDesklet->iWidth;
+	pDesklet->iKnownHeight = pDesklet->iHeight;
+	if (((pDesklet->iDesiredWidth != 0 || pDesklet->iDesiredHeight != 0) && pDesklet->iDesiredWidth == pDesklet->iWidth && pDesklet->iDesiredHeight == pDesklet->iHeight) || (pDesklet->iDesiredWidth == 0 && pDesklet->iDesiredHeight == 0))
 	{
-		pDesklet->iKnownWidth = pDesklet->iWidth;
-		pDesklet->iKnownHeight = pDesklet->iHeight;
-		if (pDesklet->iDesiredWidth == pDesklet->iWidth && pDesklet->iDesiredHeight == pDesklet->iHeight)
+		pDesklet->iDesiredWidth = 0;
+		pDesklet->iDesiredHeight = 0;
+		
+		cairo_t *pCairoContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDesklet));
+		cairo_dock_load_desklet_decorations (pDesklet, pCairoContext);
+		cairo_destroy (pCairoContext);
+		
+		if (pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL)
 		{
-			pDesklet->iDesiredWidth = 0;
-			pDesklet->iDesiredHeight = 0;
+			cairo_dock_reload_module_instance (pDesklet->pIcon->pModuleInstance, FALSE);
+			gtk_widget_queue_draw (pDesklet->pWidget);  // sinon on ne redessine que l'interieur.
 		}
-		cairo_dock_reload_module_instance (pDesklet->pIcon->pModuleInstance, FALSE);
-		gtk_widget_queue_draw (pDesklet->pWidget);  // sinon on ne redessine que l'interieur.
 	}
+	
+	//g_print ("iWidth <- %d;iHeight <- %d ; (%dx%d) (%x)\n", pDesklet->iWidth, pDesklet->iHeight, pDesklet->iKnownWidth, pDesklet->iKnownHeight, pDesklet->pIcon);
 	return FALSE;
 }
 static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
@@ -165,6 +270,26 @@ static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
 			G_TYPE_INT, "Desklet", "x position", iRelativePositionX,
 			G_TYPE_INT, "Desklet", "y position", iRelativePositionY,
 			G_TYPE_INVALID);
+		
+		/*GdkBitmap* pShapeBitmap = (GdkBitmap*) gdk_pixmap_new (NULL, pDesklet->iWidth, pDesklet->iHeight, 1);
+		cairo_t* pCairoContext = gdk_cairo_create (pShapeBitmap);
+		if (cairo_status (pCairoContext) == CAIRO_STATUS_SUCCESS)
+		{
+			cairo_set_source_rgb (pCairoContext, 1, 1, 1);
+			cairo_paint (pCairoContext);
+			cairo_destroy (pCairoContext);
+		
+		
+			gtk_widget_input_shape_combine_mask (pDesklet->pWidget,
+				NULL,
+				0,
+				0);
+			gtk_widget_input_shape_combine_mask (pDesklet->pWidget,
+				pShapeBitmap,
+				0,
+				0);
+		}
+		g_object_unref ((gpointer) pShapeBitmap);*/
 	}
 	pDesklet->iSidWritePosition = 0;
 	return FALSE;
@@ -176,6 +301,12 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 	//cd_debug ("%s (%dx%d ; %d,%d)", __func__, pEvent->width, pEvent->height, (int) pEvent->x, (int) pEvent->y);
 	if (pDesklet->iWidth != pEvent->width || pDesklet->iHeight != pEvent->height)
 	{
+		if ((pEvent->width < pDesklet->iWidth || pEvent->height < pDesklet->iHeight) && (pDesklet->iDesiredWidth != 0 && pDesklet->iDesiredHeight != 0))
+		{
+			gdk_window_resize (pDesklet->pWidget->window,
+				pDesklet->iDesiredWidth,
+				pDesklet->iDesiredHeight);
+		}
 		pDesklet->iWidth = pEvent->width;
 		pDesklet->iHeight = pEvent->height;
 		
@@ -183,6 +314,7 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 		{
 			g_source_remove (pDesklet->iSidWriteSize);
 		}
+		g_print ("on lance l'ecriture differee (%dx%d)\n", pDesklet->iWidth, pDesklet->iHeight);
 		pDesklet->iSidWriteSize = g_timeout_add (500, (GSourceFunc) _cairo_dock_write_desklet_size, (gpointer) pDesklet);
 	}
 
@@ -197,6 +329,7 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 		}
 		pDesklet->iSidWritePosition = g_timeout_add (500, (GSourceFunc) _cairo_dock_write_desklet_position, (gpointer) pDesklet);
 	}
+	pDesklet->moving = FALSE;
 
 	return FALSE;
 }
@@ -246,7 +379,7 @@ Icon *cairo_dock_find_clicked_icon_in_desklet (CairoDesklet *pDesklet)
 	return NULL;
 }
 
-static gboolean on_button_press_desklet(GtkWidget *widget,
+static gboolean on_button_press_desklet(GtkWidget *pWidget,
 	GdkEventButton *pButton,
 	CairoDesklet *pDesklet)
 {
@@ -257,6 +390,15 @@ static gboolean on_button_press_desklet(GtkWidget *widget,
 			pDesklet->diff_x = - pButton->x;  // pour le deplacement manuel.
 			pDesklet->diff_y = - pButton->y;
 			cd_debug ("diff : %d;%d", pDesklet->diff_x, pDesklet->diff_y);
+			
+			if (pButton->x < CAIRO_DOCK_DESKLET_BUTTONS_SIZE && pButton->y < CAIRO_DOCK_DESKLET_BUTTONS_SIZE)
+				pDesklet->rotating = TRUE;
+			else if (pButton->x > pDesklet->iWidth - CAIRO_DOCK_DESKLET_BUTTONS_SIZE && pButton->y < CAIRO_DOCK_DESKLET_BUTTONS_SIZE)
+			{
+				pDesklet->retaching = TRUE;
+			}
+			else
+				pDesklet->time = pButton->time;
 		}
 		else if (pButton->type == GDK_BUTTON_RELEASE)
 		{
@@ -265,6 +407,28 @@ static gboolean on_button_press_desklet(GtkWidget *widget,
 			{
 				pDesklet->moving = FALSE;
 			}
+			else if (pDesklet->rotating)
+			{
+				pDesklet->rotating = FALSE;
+				cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
+					G_TYPE_INT, "Desklet", "rotation", (int) (pDesklet->fRotation / G_PI * 180.),
+					G_TYPE_INVALID);
+				gtk_widget_queue_draw (pDesklet->pWidget);
+			}
+			else if (pDesklet->retaching)
+			{
+				pDesklet->retaching = FALSE;
+				if (! pDesklet->bPositionLocked && pButton->x > pDesklet->iWidth - CAIRO_DOCK_DESKLET_BUTTONS_SIZE && pButton->y < CAIRO_DOCK_DESKLET_BUTTONS_SIZE)
+				{
+					Icon *icon = pDesklet->pIcon;
+					g_return_val_if_fail (CAIRO_DOCK_IS_APPLET (icon), FALSE);
+					cairo_dock_update_conf_file (icon->pModuleInstance->cConfFilePath,
+						G_TYPE_BOOLEAN, "Desklet", "initially detached", FALSE,
+						G_TYPE_INVALID);
+					cairo_dock_reload_module_instance (icon->pModuleInstance, TRUE);
+					return FALSE;
+				}
+			}
 			else
 			{
 				Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
@@ -274,9 +438,20 @@ static gboolean on_button_press_desklet(GtkWidget *widget,
 		}
 		else if (pButton->type == GDK_2BUTTON_PRESS)
 		{
-			Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
-			gpointer data[2] = {pClickedIcon, pDesklet};
-			cairo_dock_notify (CAIRO_DOCK_DOUBLE_CLICK_ICON, data);
+			if (pButton->x < CAIRO_DOCK_DESKLET_BUTTONS_SIZE && pButton->y < CAIRO_DOCK_DESKLET_BUTTONS_SIZE)
+			{
+				pDesklet->fRotation = 0.;
+				gtk_widget_queue_draw (pDesklet->pWidget);
+				cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
+					G_TYPE_INT, "Desklet", "rotation", 0,
+					G_TYPE_INVALID);
+			}
+			else
+			{
+				Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
+				gpointer data[2] = {pClickedIcon, pDesklet};
+				cairo_dock_notify (CAIRO_DOCK_DOUBLE_CLICK_ICON, data);
+			}
 		}
 	}
 	else if (pButton->button == 3 && pButton->type == GDK_BUTTON_PRESS)  // clique droit.
@@ -297,8 +472,19 @@ static gboolean on_button_press_desklet(GtkWidget *widget,
 	}
 	else if (pButton->button == 2 && pButton->type == GDK_BUTTON_PRESS)  // clique milieu.
 	{
-		gpointer data[2] = {pDesklet->pIcon, pDesklet};
-		cairo_dock_notify (CAIRO_DOCK_MIDDLE_CLICK_ICON, data);
+		if (pButton->x < CAIRO_DOCK_DESKLET_BUTTONS_SIZE && pButton->y < CAIRO_DOCK_DESKLET_BUTTONS_SIZE)
+		{
+			pDesklet->fRotation = 0.;
+			gtk_widget_queue_draw (pDesklet->pWidget);
+			cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
+				G_TYPE_INT, "Desklet", "rotation", 0,
+				G_TYPE_INVALID);
+		}
+		else
+		{
+			gpointer data[2] = {pDesklet->pIcon, pDesklet};
+			cairo_dock_notify (CAIRO_DOCK_MIDDLE_CLICK_ICON, data);
+		}
 	}
 	return FALSE;
 }
@@ -324,16 +510,36 @@ static gboolean on_motion_notify_desklet(GtkWidget *pWidget,
 	if (pMotion->state & GDK_BUTTON1_MASK && ! pDesklet->bPositionLocked)
 	{
 		cd_debug ("root : %d;%d", (int) pMotion->x_root, (int) pMotion->y_root);
-		pDesklet->moving = TRUE;
+		/*pDesklet->moving = TRUE;
 		gtk_window_move (GTK_WINDOW (pWidget),
 			pMotion->x_root + pDesklet->diff_x,
-			pMotion->y_root + pDesklet->diff_y);
+			pMotion->y_root + pDesklet->diff_y);*/
 	}
 	else  // le 'press-button' est local au sous-widget clique, alors que le 'motion-notify' est global a la fenetre; c'est donc par lui qu'on peut avoir a coup sur les coordonnees du curseur (juste avant le clic).
 	{
 		pDesklet->diff_x = -pMotion->x;
 		pDesklet->diff_y = -pMotion->y;
 	}
+	
+	if (pDesklet->rotating && ! pDesklet->bPositionLocked)
+	{
+		double alpha = atan2 (pDesklet->iHeight, - pDesklet->iWidth);
+		pDesklet->fRotation = alpha - atan2 (.5*pDesklet->iHeight - pMotion->y, pMotion->x - .5*pDesklet->iWidth);
+		while (pDesklet->fRotation > G_PI)
+			pDesklet->fRotation -= 2 * G_PI;
+		while (pDesklet->fRotation <= - G_PI)
+			pDesklet->fRotation += 2 * G_PI;
+		gtk_widget_queue_draw(pDesklet->pWidget);
+	}
+	else if (pMotion->state & GDK_BUTTON1_MASK && ! pDesklet->bPositionLocked && ! pDesklet->moving)
+	{
+		gtk_window_begin_move_drag (GTK_WINDOW (gtk_widget_get_toplevel (pWidget)),
+			1/*pButton->button*/,
+			pMotion->x_root/*pButton->x_root*/,
+			pMotion->y_root/*pButton->y_root*/,
+			pDesklet->time/*pButton->time*/);
+		pDesklet->moving = TRUE;
+	}
 	gdk_device_get_state (pMotion->device, pMotion->window, NULL, NULL);  // pour recevoir d'autres MotionNotify.
 	return FALSE;
 }
@@ -500,13 +706,14 @@ CairoDesklet *cairo_dock_create_desklet (Icon *pIcon, GtkWidget *pInteractiveWid
   return pDesklet;
 }
 
-void cairo_dock_place_desklet (CairoDesklet *pDesklet, CairoDockMinimalAppletConfig *pMinimalConfig)
+void cairo_dock_configure_desklet (CairoDesklet *pDesklet, CairoDockMinimalAppletConfig *pMinimalConfig)
 {
-	cd_message ("%s (%dx%d ; (%d,%d) ; %d,%d,%d)", __func__, pMinimalConfig->iDeskletWidth, pMinimalConfig->iDeskletHeight, pMinimalConfig->iDeskletPositionX, pMinimalConfig->iDeskletPositionY, pMinimalConfig->bKeepBelow, pMinimalConfig->bKeepAbove, pMinimalConfig->bOnWidgetLayer);
-	if (pMinimalConfig->bDeskletUseSize)
+	g_print ("%s (%dx%d ; (%d,%d) ; %d,%d,%d)\n", __func__, pMinimalConfig->iDeskletWidth, pMinimalConfig->iDeskletHeight, pMinimalConfig->iDeskletPositionX, pMinimalConfig->iDeskletPositionY, pMinimalConfig->bKeepBelow, pMinimalConfig->bKeepAbove, pMinimalConfig->bOnWidgetLayer);
+	if (pMinimalConfig->bDeskletUseSize && (pMinimalConfig->iDeskletWidth != pDesklet->iWidth || pMinimalConfig->iDeskletHeight != pDesklet->iHeight))
 	{
 		pDesklet->iDesiredWidth = pMinimalConfig->iDeskletWidth;
 		pDesklet->iDesiredHeight = pMinimalConfig->iDeskletHeight;
+		g_print ("use size\n");
 		gdk_window_resize (pDesklet->pWidget->window,
 			pMinimalConfig->iDeskletWidth,
 			pMinimalConfig->iDeskletHeight);
@@ -532,6 +739,22 @@ void cairo_dock_place_desklet (CairoDesklet *pDesklet, CairoDockMinimalAppletCon
 		cairo_dock_set_xwindow_type_hint (Xid, "_NET_WM_WINDOW_TYPE_NORMAL");
 	
 	pDesklet->bPositionLocked = pMinimalConfig->bPositionLocked;
+	pDesklet->fRotation = pMinimalConfig->iRotation / 180. * G_PI ;
+	
+	g_free (pDesklet->cDecorationTheme);
+	pDesklet->cDecorationTheme = pMinimalConfig->cDecorationTheme;
+	pMinimalConfig->cDecorationTheme = NULL;
+	cairo_dock_free_desklet_decoration (pDesklet->pUserDecoration);
+	pDesklet->pUserDecoration = pMinimalConfig->pUserDecoration;
+	pMinimalConfig->pUserDecoration = NULL;
+	
+	cd_debug ("%s (%dx%d ; %d)", __func__, pDesklet->iDesiredWidth, pDesklet->iDesiredHeight, pDesklet->iSidWriteSize);
+	if (pDesklet->iDesiredWidth == 0 && pDesklet->iDesiredHeight == 0 && pDesklet->iSidWriteSize == 0)
+	{
+		cairo_t *pCairoContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDesklet));
+		cairo_dock_load_desklet_decorations (pDesklet, pCairoContext);
+		cairo_destroy (pCairoContext);
+	}
 }
 
 
@@ -578,6 +801,9 @@ void cairo_dock_free_desklet (CairoDesklet *pDesklet)
 		pDesklet->icons = NULL;
 	}
 	
+	g_free (pDesklet->cDecorationTheme);
+	cairo_dock_free_desklet_decoration (pDesklet->pUserDecoration);
+	
 	g_free(pDesklet);
 }
 
@@ -677,3 +903,107 @@ void cairo_dock_zoom_out_desklet (CairoDesklet *pDesklet)
 	pDesklet->fZoom = 0;
 	pDesklet->iSidGrowUp = g_timeout_add (50, (GSourceFunc) _cairo_dock_grow_up_desklet, (gpointer) pDesklet);
 }
+
+
+void cairo_dock_load_desklet_decorations (CairoDesklet *pDesklet, cairo_t *pSourceContext)
+{
+	if (pDesklet->pBackGroundSurface != NULL)
+	{
+		cairo_surface_destroy (pDesklet->pBackGroundSurface);
+		pDesklet->pBackGroundSurface = NULL;
+	}
+	if (pDesklet->pForeGroundSurface != NULL)
+	{
+		cairo_surface_destroy (pDesklet->pForeGroundSurface);
+		pDesklet->pForeGroundSurface = NULL;
+	}
+	
+	CairoDeskletDecoration *pDeskletDecorations;
+	cd_message ("%s (%s)", __func__, pDesklet->cDecorationTheme);
+	if (pDesklet->cDecorationTheme == NULL || strcmp (pDesklet->cDecorationTheme, "personnal") == 0)
+		pDeskletDecorations = pDesklet->pUserDecoration;
+	else if (strcmp (pDesklet->cDecorationTheme, "default") == 0)
+		pDeskletDecorations = cairo_dock_get_desklet_decoration (g_cDeskletDecorationsName);
+	else
+		pDeskletDecorations = cairo_dock_get_desklet_decoration (pDesklet->cDecorationTheme);
+	if (pDeskletDecorations == NULL)  // peut arriver si rendering n'a pas encore charge ses decorations.
+		return ;
+	cd_debug ("pDeskletDecorations : %s (%x)", pDesklet->cDecorationTheme, pDeskletDecorations);
+	
+	double fZoomX = 0., fZoomY = 0.;
+	if  (pDeskletDecorations->cBackGroundImagePath != NULL && pDeskletDecorations->fBackGroundAlpha > 0)
+	{
+		cd_debug ("bg : %s", pDeskletDecorations->cBackGroundImagePath);
+		pDesklet->pBackGroundSurface = cairo_dock_create_surface_from_image (pDeskletDecorations->cBackGroundImagePath,
+			pSourceContext,
+			1.,  // cairo_dock_get_max_scale (pDesklet)
+			pDesklet->iWidth, pDesklet->iHeight,
+			pDeskletDecorations->iLoadingModifier,
+			&pDesklet->fImageWidth, &pDesklet->fImageHeight,
+			&fZoomX, &fZoomY);
+	}
+	if (pDeskletDecorations->cForeGroundImagePath != NULL && pDeskletDecorations->fForeGroundAlpha > 0)
+	{
+		cd_debug ("fg : %s", pDeskletDecorations->cForeGroundImagePath);
+		pDesklet->pForeGroundSurface = cairo_dock_create_surface_from_image (pDeskletDecorations->cForeGroundImagePath,
+			pSourceContext,
+			1.,  // cairo_dock_get_max_scale (pDesklet)
+			pDesklet->iWidth, pDesklet->iHeight,
+			pDeskletDecorations->iLoadingModifier,
+			&pDesklet->fImageWidth, &pDesklet->fImageHeight,
+			&fZoomX, &fZoomY);
+	}
+	cd_debug ("image : %.2fx%.2f ; zoom : %.2fx%.2f", pDesklet->fImageWidth, pDesklet->fImageHeight, fZoomX, fZoomY);
+	pDesklet->iLeftSurfaceOffset = pDeskletDecorations->iLeftMargin * fZoomX;
+	pDesklet->iTopSurfaceOffset = pDeskletDecorations->iTopMargin * fZoomY;
+	pDesklet->iRightSurfaceOffset = pDeskletDecorations->iRightMargin * fZoomX;
+	pDesklet->iBottomSurfaceOffset = pDeskletDecorations->iBottomMargin * fZoomY;
+	pDesklet->fBackGroundAlpha = pDeskletDecorations->fBackGroundAlpha;
+	pDesklet->fForeGroundAlpha = pDeskletDecorations->fForeGroundAlpha;
+	cd_debug ("%d;%d;%d;%d ; %.2f;%.2f", pDesklet->iLeftSurfaceOffset, pDesklet->iTopSurfaceOffset, pDesklet->iRightSurfaceOffset, pDesklet->iBottomSurfaceOffset, pDesklet->fBackGroundAlpha, pDesklet->fForeGroundAlpha);
+}
+
+
+void cairo_dock_free_minimal_config (CairoDockMinimalAppletConfig *pMinimalConfig)
+{
+	if (pMinimalConfig == NULL)
+		return;
+	g_free (pMinimalConfig->cLabel);
+	g_free (pMinimalConfig->cIconFileName);
+	g_free (pMinimalConfig->cDockName);
+	g_free (pMinimalConfig->cDecorationTheme);
+	cairo_dock_free_desklet_decoration (pMinimalConfig->pUserDecoration);
+	g_free (pMinimalConfig);
+}
+
+
+static gboolean _cairo_dock_reload_one_desklet_decorations (CairoDesklet *pDesklet, CairoDockModuleInstance *pInstance, gpointer *data)
+{
+	gboolean bDefaultThemeOnly = GPOINTER_TO_INT (data[0]);
+	cairo_t *pSourceContext = data[1];
+	
+	if (bDefaultThemeOnly)
+	{
+		if (pDesklet->cDecorationTheme == NULL || strcmp (pDesklet->cDecorationTheme, "default") == 0)
+		{
+			cd_message ("on recharge les decorations de ce desklet");
+			cairo_dock_load_desklet_decorations (pDesklet, pSourceContext);
+		}
+	}
+	else  // tous ceux qui ne sont pas encore charges et qui ont leur taille definitive.
+	{
+		cd_debug ("pouet %dx%d ; %d ; %x;%x", pDesklet->iDesiredWidth, pDesklet->iDesiredHeight, pDesklet->iSidWriteSize, pDesklet->pBackGroundSurface, pDesklet->pForeGroundSurface);
+		if (pDesklet->iDesiredWidth == 0 && pDesklet->iDesiredHeight == 0 && pDesklet->iSidWriteSize == 0 && pDesklet->pBackGroundSurface == NULL && pDesklet->pForeGroundSurface == NULL)
+		{
+			cd_message ("ce desklet a saute le chargement de ses deco => on l'aide.");
+			cairo_dock_load_desklet_decorations (pDesklet, pSourceContext);
+		}
+	}
+	return FALSE;
+}
+void cairo_dock_reload_desklets_decorations (gboolean bDefaultThemeOnly, cairo_t *pSourceContext)  // tous ou bien seulement ceux avec "default".
+{
+	cd_message ("%s (%d)", __func__, bDefaultThemeOnly);
+	gpointer data[2] = {GINT_TO_POINTER (bDefaultThemeOnly), pSourceContext};
+	cairo_dock_foreach_desklet ((CairoDockForeachDeskletFunc)_cairo_dock_reload_one_desklet_decorations, data);
+}
