@@ -74,6 +74,7 @@ extern gboolean g_bPopUp;
 extern gboolean g_bSkipPager;
 extern gboolean g_bSkipTaskbar;
 extern gboolean g_bSticky;
+extern gboolean g_bUseFakeTransparency;
 
 extern gboolean g_bUseGlitz;
 
@@ -111,7 +112,9 @@ CairoDock *cairo_dock_create_new_dock (GdkWindowTypeHint iWmHint, gchar *cDockNa
 	if (g_bKeepAbove)
 		gtk_window_set_keep_above (GTK_WINDOW (pWindow), g_bKeepAbove);
 	if (g_bPopUp)
-		gtk_window_set_keep_below (GTK_WINDOW (pWindow), g_bPopUp);
+		gtk_window_set_keep_below (GTK_WINDOW (pWindow), TRUE);
+	if (g_bUseFakeTransparency)
+		gtk_window_set_keep_below (GTK_WINDOW (pWindow), TRUE);
 	gtk_window_set_skip_pager_hint (GTK_WINDOW (pWindow), g_bSkipPager);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (pWindow), g_bSkipTaskbar);
 	gtk_window_set_gravity (GTK_WINDOW (pWindow), GDK_GRAVITY_STATIC);
@@ -537,10 +540,11 @@ CairoDock *cairo_dock_create_subdock_from_scratch_with_type (GList *pIconList, g
 	return pSubDock;
 }
 
-static void _cairo_dock_update_child_dock_size (gchar *cDockName, CairoDock *pDock, gpointer data)
+/*static void _cairo_dock_update_child_dock_size (gchar *cDockName, CairoDock *pDock, gpointer data)
 {
 	if (! pDock->bIsMainDock)
 	{
+		gtk_widget_queue_draw (pDock->pWidget);
 		cd_message ("  %s (%s)", __func__, cDockName);
 		cairo_dock_update_dock_size (pDock);
 		///pDock->iMouseX = -1; // utile ?
@@ -554,7 +558,7 @@ static void _cairo_dock_update_child_dock_size (gchar *cDockName, CairoDock *pDo
 		else
 			gtk_window_move (GTK_WINDOW (pDock->pWidget), 500, 500);  // sinon ils n'apparaisesent pas.
 	}
-}
+}*/
 void cairo_dock_build_docks_tree_with_desktop_files (CairoDock *pMainDock, gchar *cDirectory)
 {
 	cd_message ("%s (%s)", __func__, cDirectory);
@@ -589,6 +593,8 @@ void cairo_dock_build_docks_tree_with_desktop_files (CairoDock *pMainDock, gchar
 	g_dir_close (dir);
 	cairo_destroy (pCairoContext);
 	//g_hash_table_foreach (s_hDocksTable, (GHFunc) _cairo_dock_update_child_dock_size, NULL);  // on mettra a jour la taille du dock principal apres y avoir insere les applis/applets, car pour l'instant les docks fils n'en ont pas.
+	cairo_dock_redraw_root_docks (TRUE);
+
 }
 
 void cairo_dock_free_all_docks (void)
@@ -704,7 +710,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	gboolean bSeparatorNeeded = FALSE;
 	if (bInsertSeparator && ! CAIRO_DOCK_IS_SEPARATOR (icon))
 	{
-		Icon *pSameTypeIcon = cairo_dock_get_first_icon_of_type (pDock->icons, icon->iType);
+		Icon *pSameTypeIcon = cairo_dock_get_first_icon_of_order (pDock->icons, icon->iType);
 		if (pSameTypeIcon == NULL && pDock->icons != NULL)
 		{
 			bSeparatorNeeded = TRUE;
@@ -715,7 +721,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	//\______________ On insere l'icone a sa place dans la liste.
 	if (icon->fOrder == CAIRO_DOCK_LAST_ORDER)
 	{
-		Icon *pLastIcon = cairo_dock_get_last_icon_of_type (pDock->icons, icon->iType);
+		Icon *pLastIcon = cairo_dock_get_last_icon_of_order (pDock->icons, icon->iType);
 		if (pLastIcon != NULL)
 			icon->fOrder = pLastIcon->fOrder + 1;
 		else
@@ -752,10 +758,11 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 		if (iOrder + 1 < CAIRO_DOCK_NB_TYPES)
 		{
 			Icon *pNextIcon = cairo_dock_get_next_icon (pDock->icons, icon);
-			if (pNextIcon != NULL && ((pNextIcon->iType - icon->iType) % 2 == 0))
+			if (pNextIcon != NULL && ((cairo_dock_get_icon_order (pNextIcon) - cairo_dock_get_icon_order (icon)) % 2 == 0) && (cairo_dock_get_icon_order (pNextIcon) != cairo_dock_get_icon_order (icon)))
 			{
 				int iSeparatorType = iOrder + 1;
-				cd_message (" insertion de %s -> iSeparatorType : %d", icon->acName, iSeparatorType);
+				//int iSeparatorType = icon->iType + 1;
+				g_print (" insertion de %s avant %s -> iSeparatorType : %d\n", icon->acName, pNextIcon->acName, iSeparatorType);
 
 				cairo_t *pSourceContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDock));
 				Icon *pSeparatorIcon = cairo_dock_create_separator_icon (pSourceContext, iSeparatorType, pDock, bApplyRatio);
@@ -773,10 +780,11 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 		if (iOrder > 1)
 		{
 			Icon *pPrevIcon = cairo_dock_get_previous_icon (pDock->icons, icon);
-			if (pPrevIcon != NULL && ((pPrevIcon->iType - icon->iType) % 2 == 0))
+			if (pPrevIcon != NULL && ((cairo_dock_get_icon_order (pPrevIcon) - cairo_dock_get_icon_order (icon)) % 2 == 0) && (cairo_dock_get_icon_order (pPrevIcon) != cairo_dock_get_icon_order (icon)))
 			{
 				int iSeparatorType = iOrder - 1;
-				cd_message (" insertion de %s -> iSeparatorType : %d", icon->acName, iSeparatorType);
+				//int iSeparatorType = icon->iType - 1;
+				g_print (" insertion de %s apres %s -> iSeparatorType : %d\n", icon->acName, pPrevIcon->acName, iSeparatorType);
 
 				cairo_t *pSourceContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDock));
 				Icon *pSeparatorIcon = cairo_dock_create_separator_icon (pSourceContext, iSeparatorType, pDock, bApplyRatio);
