@@ -41,6 +41,9 @@ extern gint g_iStringLineWidth;
 extern double g_fStringColor[4];
 extern double g_fReflectSize;
 
+extern double g_fAmplitude;
+extern int g_iSinusoidWidth;
+
 extern gboolean g_bRoundedBottomCorner;
 extern gboolean bDirectionUp;
 extern double g_fStripesSpeedFactor;
@@ -352,7 +355,7 @@ void cairo_dock_render_decorations_in_frame (cairo_t *pCairoContext, CairoDock *
 			cairo_scale (pCairoContext, 1. * pDock->iDecorationsHeight / g_fBackgroundImageHeight, 1. * fWidth / g_fBackgroundImageWidth);
 		}
 		
-		//g_print ("(%dx%d) / (%dx%d)\n", pDock->iCurrentWidth, pDock->iMaxIconHeight, (int) g_fBackgroundImageWidth, (int) g_fBackgroundImageHeight);
+		//g_print ("(%dx%d) / (%dx%d)\n", pDock->iCurrentWidth, (int) pDock->iMaxIconHeight, (int) g_fBackgroundImageWidth, (int) g_fBackgroundImageHeight);
 		cairo_set_source_surface (pCairoContext, g_pBackgroundSurface[pDock->bHorizontalDock], 0., 0.);
 		cairo_fill_preserve (pCairoContext);
 		cairo_restore (pCairoContext);
@@ -572,18 +575,33 @@ void cairo_dock_render_one_icon (Icon *icon, cairo_t *pCairoContext, gboolean bH
 			icon->fAlpha *= MIN (g_fVisibleAppliAlpha + 1, 1);*/
 		//g_print ("g_fVisibleAppliAlpha : %.2f & %d => %.2f\n", g_fVisibleAppliAlpha, icon->bIsHidden, icon->fAlpha);
 	}
+	
 	double fGlideScale;
 	if (icon->fGlideOffset != 0)
 	{
-		fGlideScale = -.5*fabs(icon->fGlideOffset)+1;
-		fGlideScale = MAX (fGlideScale, 1/icon->fScale);
+		double fPhase =  icon->fPhase + icon->fGlideOffset * icon->fWidth / fRatio / g_iSinusoidWidth * G_PI;
+		if (fPhase < 0)
+		{
+			fPhase = 0;
+		}
+		else if (fPhase > G_PI)
+		{
+			fPhase = G_PI;
+		}
+		fGlideScale = (1 + fDockMagnitude * g_fAmplitude * sin (fPhase)) / icon->fScale;  // c'est un peu hacky ... il faudrait passer l'icone precedente en parametre ...
+		if (bDirectionUp)
+			if (bHorizontalDock)
+				cairo_translate (pCairoContext, 0., (1-fGlideScale)*icon->fHeight*icon->fScale);
+			else
+				cairo_translate (pCairoContext, (1-fGlideScale)*icon->fHeight*icon->fScale, 0.);
 	}
 	else
 		fGlideScale = 1;
+	
 	if (bHorizontalDock)
-		cairo_translate (pCairoContext, icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * fGlideScale, icon->fDrawY + (1-fGlideScale)*icon->fHeight*icon->fScale);
+		cairo_translate (pCairoContext, icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * (icon->fGlideOffset < 0 ? fGlideScale : 1), icon->fDrawY);
 	else
-		cairo_translate (pCairoContext, icon->fDrawY, icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * fGlideScale);
+		cairo_translate (pCairoContext, icon->fDrawY, icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * (icon->fGlideOffset < 0 ? fGlideScale : 1));
 	
 	if (icon->bHasIndicator && ! g_bIndicatorAbove && g_pIndicatorSurface[0] != NULL)
 	{
@@ -652,7 +670,7 @@ void cairo_dock_render_one_icon (Icon *icon, cairo_t *pCairoContext, gboolean bH
 		cairo_save (pCairoContext);
 		if (icon->fWidth / fRatio != g_fActiveIndicatorWidth || icon->fHeight / fRatio != g_fActiveIndicatorHeight)
 		{
-			cairo_scale (pCairoContext, icon->fWidth / fRatio / g_fActiveIndicatorWidth, icon->fHeight / fRatio / g_fActiveIndicatorHeight);
+			cairo_scale (pCairoContext, icon->fWidth * icon->fWidthFactor * 1 / fRatio / g_fActiveIndicatorWidth, icon->fHeight * icon->fHeightFactor * 1 / fRatio / g_fActiveIndicatorHeight);
 		}
 		cairo_set_source_surface (pCairoContext, g_pActiveIndicatorSurface, 0., 0.);
 		cairo_paint (pCairoContext);
@@ -786,43 +804,19 @@ void cairo_dock_render_one_icon (Icon *icon, cairo_t *pCairoContext, gboolean bH
 			cairo_paint_with_alpha (pCairoContext, fAlpha);
 	}
 	
+	cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
+
 	if (icon->Xid != 0 && icon->Xid == cairo_dock_get_current_active_window () && g_bActiveIndicatorAbove && g_pActiveIndicatorSurface != NULL)
 	{
-		//cairo_save (pCairoContext);
-		if (icon->fWidth / fRatio != g_fActiveIndicatorWidth || icon->fHeight / fRatio != g_fActiveIndicatorHeight)
+		cairo_save (pCairoContext);
+		if (icon->fWidth / 1. / (1 + g_fAmplitude) != g_fActiveIndicatorWidth || icon->fHeight / 1. / (1 + g_fAmplitude) != g_fActiveIndicatorHeight)
 		{
-			cairo_scale (pCairoContext, icon->fWidth / fRatio / g_fActiveIndicatorWidth, icon->fHeight / fRatio / g_fActiveIndicatorHeight);
+			cairo_scale (pCairoContext, icon->fWidth * icon->fWidthFactor / 1. / g_fActiveIndicatorWidth * icon->fScale / (1 + g_fAmplitude), icon->fHeight * icon->fHeightFactor / 1. / g_fActiveIndicatorHeight * icon->fScale / (1 + g_fAmplitude));
 		}
 		cairo_set_source_surface (pCairoContext, g_pActiveIndicatorSurface, 0., 0.);
 		cairo_paint (pCairoContext);
-		//cairo_restore (pCairoContext);
+		cairo_restore (pCairoContext);
 	}
-	/* Voici ton bloque d'origine, j'ai remanier pour adapter a mes modifications
-	if (icon->Xid != 0 && icon->Xid == cairo_dock_get_current_active_window ())
-	{
-		cairo_dock_draw_frame (pCairoContext,
-				g_iActiveRadius,
-				g_iActiveLineWidth,
-				MAX (1., icon->fWidth * (1+g_fAmplitude) / fRatio - (2 * g_iActiveRadius + g_iActiveLineWidth)),
-				icon->fHeight * (1+g_fAmplitude) / fRatio - 2*g_iActiveLineWidth,
-				g_iActiveRadius + .5*g_iActiveLineWidth,
-				.5*g_iActiveLineWidth * 1,
-				1, 0., CAIRO_DOCK_HORIZONTAL);
-		//cairo_rectangle (pCairoContext, 0., 0., icon->fWidth * (1+g_fAmplitude), icon->fHeight * (1+g_fAmplitude));
-		cairo_set_source_rgba (pCairoContext, g_fActiveColor[0], g_fActiveColor[1], g_fActiveColor[2], g_fActiveColor[3]);
-		if (g_iActiveLineWidth > 0)
-		{
-				cairo_set_line_width (pCairoContext, g_iActiveLineWidth);
-				cairo_stroke (pCairoContext);
-		}
-		else
-		{
-				cairo_fill (pCairoContext);
-		}
-	}
-	*/
-	
-	cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
 	
 	if (icon->bHasIndicator && g_bIndicatorAbove && g_pIndicatorSurface[0] != NULL)
 	{
@@ -1203,6 +1197,7 @@ void cairo_dock_render_icons_linear (cairo_t *pCairoContext, CairoDock *pDock, d
 
 void cairo_dock_render_background (cairo_t *pCairoContext, CairoDock *pDock)
 {
+	//g_print ("%s (%d, %x)\n", __func__, pDock->bIsMainDock, g_pVisibleZoneSurface);
 	if (g_pVisibleZoneSurface != NULL)
 	{
 		cairo_set_source_surface (pCairoContext, g_pVisibleZoneSurface, 0.0, 0.0);
@@ -1261,6 +1256,14 @@ void cairo_dock_redraw_my_icon (Icon *icon, CairoContainer *pContainer)
 void cairo_dock_set_window_position_at_balance (CairoDock *pDock, int iNewWidth, int iNewHeight)
 {
 	pDock->iWindowPositionX = (g_iScreenWidth[pDock->bHorizontalDock] - iNewWidth) * pDock->fAlign + pDock->iGapX;
+	/*if (pDock->fAlign < 0.5)
+	{
+		pDock->iWindowPositionX += pDock->iLeftMargin * (0.5 - pDock->fAlign)*2;
+	}
+	else
+	{
+		pDock->iWindowPositionX += pDock->iRightMargin * (pDock->fAlign - 0.5)*2;
+	}*/
 	pDock->iWindowPositionY = (pDock->bDirectionUp ? g_iScreenHeight[pDock->bHorizontalDock] - iNewHeight - pDock->iGapY : pDock->iGapY);
 	//g_print ("pDock->iGapX : %d => iWindowPositionX <- %d\n", pDock->iGapX, pDock->iWindowPositionX);
 	//g_print ("iNewHeight : %d -> pDock->iWindowPositionY <- %d\n", iNewHeight, pDock->iWindowPositionY);
@@ -1282,16 +1285,22 @@ void cairo_dock_get_window_position_and_geometry_at_balance (CairoDock *pDock, C
 	{
 		*iNewWidth = pDock->iMaxDockWidth;
 		*iNewHeight = pDock->iMaxDockHeight;
+		pDock->iLeftMargin = pDock->iMaxLeftMargin;
+		pDock->iRightMargin = pDock->iMaxRightMargin;
 	}
 	else if (iSizeType == CAIRO_DOCK_NORMAL_SIZE)
 	{
 		*iNewWidth = pDock->iMinDockWidth;
 		*iNewHeight = pDock->iMinDockHeight;
+		pDock->iLeftMargin = pDock->iMinLeftMargin;
+		pDock->iRightMargin = pDock->iMinRightMargin;
 	}
 	else
 	{
 		*iNewWidth = g_iVisibleZoneWidth;
 		*iNewHeight = g_iVisibleZoneHeight;
+		pDock->iLeftMargin = 0;
+		pDock->iRightMargin = 0;
 	}
 
 	cairo_dock_set_window_position_at_balance (pDock, *iNewWidth, *iNewHeight);
@@ -1341,6 +1350,7 @@ void cairo_dock_draw_drop_indicator (CairoDock *pDock, cairo_t *pCairoContext)
 	//cairo_move_to (pCairoContext, fX, pDock->iDropIndicatorOffset);
 	cairo_translate (pCairoContext, 0, pDock->iDropIndicatorOffset);
 	cairo_pattern_t* pPattern = cairo_pattern_create_for_surface (g_pDropIndicatorSurface);
+	g_return_if_fail (cairo_pattern_status (pPattern) == CAIRO_STATUS_SUCCESS);
 	cairo_pattern_set_extend (pPattern, CAIRO_EXTEND_REPEAT);
 	cairo_set_source (pCairoContext, pPattern);
 	
