@@ -82,7 +82,7 @@ gboolean cairo_dock_fm_launch_uri (const gchar *cURI)
 		GThread* pThread = g_thread_create ((GThreadFunc) _cairo_dock_fm_launch_uri_threaded, (gpointer) cURI, FALSE, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("Attention : %s", erreur->message);
+			cd_warning (erreur->message);
 			g_error_free (erreur);
 		}
 		return TRUE;
@@ -239,6 +239,17 @@ gboolean cairo_dock_fm_logout (void)
 		return FALSE;
 }
 
+gboolean cairo_dock_fm_shutdown (void)
+{
+	if (s_pVFSBackend != NULL && s_pVFSBackend->shutdown!= NULL)
+	{
+		s_pVFSBackend->shutdown ();
+		return TRUE;
+	}
+	else
+		return FALSE;
+}
+
 gboolean cairo_dock_fm_setup_time (void)
 {
 	if (s_pVFSBackend != NULL && s_pVFSBackend->setup_time!= NULL)
