@@ -14,9 +14,10 @@ Written by Fabrice Rey (for any bug report, please mail me to fabounet@users.ber
 #include <glib/gi18n.h>
 
 #include "cairo-dock-modules.h"
-#include "cairo-dock-gui-factory.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-animations.h"
 #include "cairo-dock-applet-facility.h"
+#include "cairo-dock-gui-factory.h"
 
 #define CAIRO_DOCK_GUI_MARGIN 4
 #define CAIRO_DOCK_ICON_MARGIN 6
@@ -26,11 +27,7 @@ Written by Fabrice Rey (for any bug report, please mail me to fabounet@users.ber
 #define CAIRO_DOCK_TAB_ICON_SIZE 32
 #define CAIRO_DOCK_FRAME_ICON_SIZE 24
 
-#ifndef mkstemp
-int mkstemp(char *template);
-#endif
-
-extern gboolean g_bPopUp;
+extern CairoDock *g_pMainDock;
 
 typedef enum {
 	CAIRO_DOCK_MODEL_NAME = 0,
@@ -44,6 +41,8 @@ typedef enum {
 	} _CairoDockModelColumns;
 
 static GtkListStore *s_pRendererListStore = NULL;
+static GtkListStore *s_pDecorationsListStore = NULL;
+static GtkListStore *s_pDecorationsListStore2 = NULL;
 
 static void _cairo_dock_activate_one_element (GtkCellRendererToggle * cell_renderer, gchar * path, GtkTreeModel * model)
 {
@@ -575,8 +574,39 @@ void cairo_dock_build_renderer_list_for_gui (GHashTable *pHashTable)
 	_cairo_dock_add_one_renderer_item ("", NULL, s_pRendererListStore);
 	g_hash_table_foreach (pHashTable, (GHFunc) _cairo_dock_add_one_renderer_item, s_pRendererListStore);
 }
+void _cairo_dock_add_one_decoration_item (gchar *cName, CairoDeskletDecoration *pDecoration, GtkListStore *pModele)
+{
+	g_print ("add %s\n", cName);
+	GtkTreeIter iter;
+	memset (&iter, 0, sizeof (GtkTreeIter));
+	gtk_list_store_append (GTK_LIST_STORE (pModele), &iter);
+	gtk_list_store_set (GTK_LIST_STORE (pModele), &iter,
+		CAIRO_DOCK_MODEL_NAME, cName,
+		CAIRO_DOCK_MODEL_RESULT, cName,
+		CAIRO_DOCK_MODEL_DESCRIPTION_FILE, "none"/*(pRenderer != NULL ? pRenderer->cReadmeFilePath : "none")*/,
+		CAIRO_DOCK_MODEL_IMAGE, "none"/*(pRenderer != NULL ? pRenderer->cPreviewFilePath : "none")*/, -1);
+}
+void cairo_dock_build_desklet_decorations_list_for_gui (GHashTable *pHashTable)
+{
+	if (s_pDecorationsListStore != NULL)
+		g_object_unref (s_pDecorationsListStore);
+	
+	s_pDecorationsListStore = gtk_list_store_new (CAIRO_DOCK_MODEL_NB_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF);
+	
+	g_hash_table_foreach (pHashTable, (GHFunc) _cairo_dock_add_one_decoration_item, s_pDecorationsListStore);
+}
+void cairo_dock_build_desklet_decorations_list_for_applet_gui (GHashTable *pHashTable)
+{
+	if (s_pDecorationsListStore2 != NULL)
+		g_object_unref (s_pDecorationsListStore2);
+	
+	s_pDecorationsListStore2 = gtk_list_store_new (CAIRO_DOCK_MODEL_NB_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF);
+	
+	_cairo_dock_add_one_decoration_item ("default", NULL, s_pDecorationsListStore2);
+	g_hash_table_foreach (pHashTable, (GHFunc) _cairo_dock_add_one_decoration_item, s_pDecorationsListStore2);
+}
 
-static gboolean _cairo_dock_test_one_renderer_name (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer *data)
+static gboolean _cairo_dock_test_one_name (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer *data)
 {
 	gchar *cName = NULL;
 	gtk_tree_model_get (model, iter, CAIRO_DOCK_MODEL_NAME, &cName, -1);
@@ -590,16 +620,17 @@ static gboolean _cairo_dock_test_one_renderer_name (GtkTreeModel *model, GtkTree
 	}
 	return FALSE;
 }
-gboolean _cairo_dock_find_iter_from_renderer_name (gchar *cName, GtkTreeIter *iter)
+static gboolean _cairo_dock_find_iter_from_name (GtkListStore *pModele, gchar *cName, GtkTreeIter *iter)
 {
 	if (cName == NULL)
 		return FALSE;
 	gboolean bFound = FALSE;
 	gpointer data[3] = {cName, iter, &bFound};
-	gtk_tree_model_foreach (GTK_TREE_MODEL (s_pRendererListStore), (GtkTreeModelForeachFunc) _cairo_dock_test_one_renderer_name, data);
+	gtk_tree_model_foreach (GTK_TREE_MODEL (pModele), (GtkTreeModelForeachFunc) _cairo_dock_test_one_name, data);
 	return bFound;
 }
 
+
 static void _cairo_dock_configure_renderer (GtkButton *button, gpointer *data)
 {
 	GtkTreeView *pCombo = data[0];
@@ -608,6 +639,29 @@ static void _cairo_dock_configure_renderer (GtkButton *button, gpointer *data)
 	cairo_dock_configure_module (pDialog, "rendering");
 }
 
+static int iNbConfigDialogs = 0;
+int cairo_dock_get_nb_config_panels (void)
+{
+	return iNbConfigDialogs;
+}
+void cairo_dock_config_panel_destroyed (void)
+{
+	iNbConfigDialogs --;
+	if (iNbConfigDialogs <= 0)
+	{
+		g_print ("plus de panneaux de config\n");
+		iNbConfigDialogs = 0;
+		if (g_pMainDock != NULL)  // peut arriver au 1er lancement.
+			cairo_dock_pop_down (g_pMainDock);
+	}
+}
+void cairo_dock_config_panel_created (void)
+{
+	iNbConfigDialogs ++;
+	g_print ("nbre de panneaux de config <- %d\n", iNbConfigDialogs);
+}
+
+
 #define _allocate_new_buffer\
 	data = g_new (gpointer, 3); \
 	g_ptr_array_add (pDataGarbage, data);
@@ -615,6 +669,7 @@ static void _cairo_dock_configure_renderer (GtkButton *button, gpointer *data)
 #define _allocate_new_model\
 	modele = gtk_list_store_new (CAIRO_DOCK_MODEL_NB_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF);
 
+
 GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, const gchar *cTitle, GtkWindow *pParentWindow, GSList **pWidgetList, gboolean bApplyButtonPresent, gchar iIdentifier, gchar *cPresentedGroup, gboolean bSwitchButtonPresent, gchar *cButtonConvert, gchar *cGettextDomain, GPtrArray *pDataGarbage)
 {
 	g_return_val_if_fail (cairo_dock_is_advanced_keyfile (pKeyFile), NULL);
@@ -644,6 +699,8 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 	GtkWidget *pDescriptionLabel;
 	GtkWidget *pPreviewImage;
 	GtkWidget *pButtonConfigRenderer;
+	GtkCellRenderer *rend;
+	GtkTreeIter iter;
 	gchar *cGroupName, *cGroupComment , *cKeyName, *cKeyComment, *cUsefulComment, *cAuthorizedValuesChain, *pTipString, **pAuthorizedValuesList, *cSmallGroupIcon;
 	gpointer *pGroupKeyWidget;
 	int i, j, k, iNbElements;
@@ -656,12 +713,11 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 	gchar *cValue, **cValueList, *cSmallIcon;
 	GdkColor gdkColor;
 	GtkListStore *modele;
-	//if (g_bPopUp)
-	//	pParentWindow = NULL;
 	
 	GtkWidget *pDialog;
 	if (bApplyButtonPresent)
 	{
+		pParentWindow = NULL;  // evite de la rendre modale, et ainsi la fait apparaitre dans la barre des taches.
 		if (bSwitchButtonPresent)
 		pDialog = gtk_dialog_new_with_buttons ((cTitle != NULL ? cTitle : ""),
 			(pParentWindow != NULL ? GTK_WINDOW (pParentWindow) : NULL),
@@ -699,14 +755,6 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 			NULL);
 	}
 	
-	if (g_bPopUp)  /// faire quelque chose pour pas que le dock passe en arriere-plan et pDialog avec...
-	{
-		/*gtk_window_set_keep_above (GTK_WINDOW (pDialog), TRUE);
-		gtk_window_set_keep_below (GTK_WINDOW (pDialog), FALSE);
-		gtk_window_present (GTK_WINDOW (pDialog));
-		gtk_window_set_modal (GTK_WINDOW (pDialog), FALSE);
-		gtk_window_set_transient_for (GTK_WINDOW (pDialog), NULL);*/
-	}
 	gchar *cIconPath = g_strdup_printf ("%s/%s", CAIRO_DOCK_SHARE_DATA_DIR, CAIRO_DOCK_ICON);
 	gtk_window_set_icon_from_file (GTK_WINDOW (pDialog), cIconPath, NULL);
 	g_free (cIconPath);
@@ -1074,7 +1122,7 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 						cValue = g_key_file_get_string (pKeyFile, cGroupName, cKeyName, NULL);
 						modele = s_pRendererListStore;
 						pOneWidget = gtk_combo_box_new_with_model (GTK_TREE_MODEL (modele));
-						GtkCellRenderer *rend = gtk_cell_renderer_text_new ();
+						rend = gtk_cell_renderer_text_new ();
 						gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (pOneWidget), rend, FALSE);
 						gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (pOneWidget), rend, "text", CAIRO_DOCK_MODEL_NAME, NULL);
 						
@@ -1103,8 +1151,7 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 							FALSE,
 							0);
 						
-						GtkTreeIter iter;
-						if (_cairo_dock_find_iter_from_renderer_name (cValue, &iter))
+						if (_cairo_dock_find_iter_from_name (modele, cValue, &iter))
 							gtk_combo_box_set_active_iter (GTK_COMBO_BOX (pOneWidget), &iter);
 						
 						pSubWidgetList = g_slist_append (pSubWidgetList, pOneWidget);
@@ -1130,6 +1177,27 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 							0);
 					break ;
 					
+					case 'd' :
+					case 'o' :
+						cValue = g_key_file_get_string (pKeyFile, cGroupName, cKeyName, NULL);
+						modele = (iElementType == 'd' ? s_pDecorationsListStore : s_pDecorationsListStore2);
+						pOneWidget = gtk_combo_box_new_with_model (GTK_TREE_MODEL (modele));
+						
+						rend = gtk_cell_renderer_text_new ();
+						gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (pOneWidget), rend, FALSE);
+						gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (pOneWidget), rend, "text", CAIRO_DOCK_MODEL_NAME, NULL);
+						
+						if (_cairo_dock_find_iter_from_name (modele, cValue, &iter))
+							gtk_combo_box_set_active_iter (GTK_COMBO_BOX (pOneWidget), &iter);
+						pSubWidgetList = g_slist_append (pSubWidgetList, pOneWidget);
+						gtk_box_pack_start (GTK_BOX (pHBox),
+							pOneWidget,
+							FALSE,
+							FALSE,
+							0);
+						g_free (cValue);
+					break ;
+					
 					case 's' :  // string
 					case 'S' :  // string avec un selecteur de fichier a cote du GtkEntry.
 					case 'u' :  // string avec un selecteur de fichier a cote du GtkEntry et un boutton play.
@@ -1669,35 +1737,6 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 						}
 					break ;
 
-					/*case 'k' :
-						cValue = g_key_file_get_string(pKeyFile, cGroupName, cKeyName, NULL);
-
-						pOneWidget = gtk_entry_new();
-						gtk_entry_set_text(GTK_ENTRY(pOneWidget), cValue);
-						GtkWidget *w = gtk_button_new_with_label("grab");
-						GtkWidget *b = gtk_hbox_new(FALSE, 0);
-						gtk_box_pack_start(GTK_BOX(b), pOneWidget, FALSE, FALSE, 0);
-						gtk_box_pack_start(GTK_BOX(b), w, FALSE, FALSE, 0);
-
-						pSubWidgetList = g_slist_append (pSubWidgetList, pOneWidget);
-						gtk_box_pack_start(GTK_BOX (pHBox),
-							b,
-							FALSE,
-							FALSE,
-							0);
-
-						_allocate_new_buffer;
-						data[0] = pOneWidget;
-						data[1] = GTK_WINDOW (pDialog);
-						gtk_widget_add_events(pDialog, GDK_KEY_PRESS_MASK);
-
-						g_signal_connect (G_OBJECT (w),
-							"clicked",
-							G_CALLBACK (_cairo_dock_key_grab_clicked),
-							data);*/
-
-					break;
-
 					default :
 						cd_warning ("this conf file seems to be incorrect !");
 					break ;
@@ -1739,7 +1778,8 @@ GtkWidget *cairo_dock_generate_advanced_ihm_from_keyfile (GKeyFile *pKeyFile, co
 		"delete-event",
 		G_CALLBACK (_cairo_dock_free_conf_widget_data),
 		user_data);*/
-		
+	
+	cairo_dock_config_panel_created ();
 	return pDialog;
 }
 
