@@ -230,8 +230,6 @@ Icon* cairo_dock_get_first_icon_of_type (GList *pIconList, CairoDockIconType iTy
 	}
 	return NULL;
 }
-
-
 Icon* cairo_dock_get_last_icon_of_type (GList *pIconList, CairoDockIconType iType)
 {
 	GList* ic;
@@ -244,6 +242,32 @@ Icon* cairo_dock_get_last_icon_of_type (GList *pIconList, CairoDockIconType iTyp
 	}
 	return NULL;
 }
+Icon* cairo_dock_get_first_icon_of_order (GList *pIconList, CairoDockIconType iType)
+{
+	int iGroupOrder = cairo_dock_get_group_order (iType);
+	GList* ic;
+	Icon *icon;
+	for (ic = pIconList; ic != NULL; ic = ic->next)
+	{
+		icon = ic->data;
+		if (cairo_dock_get_icon_order (icon) == iGroupOrder)
+			return icon;
+	}
+	return NULL;
+}
+Icon* cairo_dock_get_last_icon_of_order (GList *pIconList, CairoDockIconType iType)
+{
+	int iGroupOrder = cairo_dock_get_group_order (iType);
+	GList* ic;
+	Icon *icon;
+	for (ic = g_list_last (pIconList); ic != NULL; ic = ic->prev)
+	{
+		icon = ic->data;
+		if (cairo_dock_get_icon_order (icon) == iGroupOrder)
+			return icon;
+	}
+	return NULL;
+}
 
 Icon* cairo_dock_get_pointed_icon (GList *pIconList)
 {
@@ -420,7 +444,7 @@ Icon *cairo_dock_get_icon_with_class (GList *pIconList, gchar *cClass)
 
 void cairo_dock_normalize_icons_order (GList *pIconList, CairoDockIconType iType)
 {
-	g_print ("%s (%d)\n", __func__, iType);
+	cd_message ("%s (%d)", __func__, iType);
 	int iOrder = 1;
 	int iGroupOrder = cairo_dock_get_group_order (iType);
 	GString *sDesktopFilePath = g_string_new ("");
@@ -437,7 +461,7 @@ void cairo_dock_normalize_icons_order (GList *pIconList, CairoDockIconType iType
 		{
 			g_string_printf (sDesktopFilePath, "%s/%s", g_cCurrentLaunchersPath, icon->acDesktopFileName);
 			cairo_dock_update_conf_file (sDesktopFilePath->str,
-				G_TYPE_DOUBLE, "Icon", "order", icon->fOrder,
+				G_TYPE_DOUBLE, "Desktop Entry", "Order", icon->fOrder,
 				G_TYPE_INVALID);
 		}
 		else if (CAIRO_DOCK_IS_APPLET (icon))
@@ -475,7 +499,7 @@ void cairo_dock_swap_icons (CairoDock *pDock, Icon *icon1, Icon *icon2)
 			g_key_file_load_from_file (pKeyFile, cDesktopFilePath, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &erreur);
 			if (erreur != NULL)
 			{
-				cd_warning ("%s", erreur->message);
+				cd_warning (erreur->message);
 				g_error_free (erreur);
 				return ;
 			}
@@ -493,7 +517,7 @@ void cairo_dock_swap_icons (CairoDock *pDock, Icon *icon1, Icon *icon2)
 			g_key_file_load_from_file (pKeyFile, cDesktopFilePath, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &erreur);
 			if (erreur != NULL)
 			{
-				cd_warning ("%s", erreur->message);
+				cd_warning (erreur->message);
 				g_error_free (erreur);
 				return ;
 			}
@@ -533,54 +557,45 @@ void cairo_dock_swap_icons (CairoDock *pDock, Icon *icon1, Icon *icon2)
 
 void cairo_dock_move_icon_after_icon (CairoDock *pDock, Icon *icon1, Icon *icon2)
 {
-	//g_print ("%s (%s, %.2f)\n", __func__, icon1->acName, icon1->fOrder);
+	//g_print ("%s (%s, %.2f, %x)\n", __func__, icon1->acName, icon1->fOrder, icon2);
 	///if ((icon2 != NULL) && (! ( (CAIRO_DOCK_IS_APPLI (icon1) && CAIRO_DOCK_IS_APPLI (icon2)) || (CAIRO_DOCK_IS_LAUNCHER (icon1) && CAIRO_DOCK_IS_LAUNCHER (icon2)) || (CAIRO_DOCK_IS_APPLET (icon1) && CAIRO_DOCK_IS_APPLET (icon2)) ) ))
 	if ((icon2 != NULL) && fabs (cairo_dock_get_icon_order (icon1) - cairo_dock_get_icon_order (icon2)) > 1)
 		return ;
 	//\_________________ On change l'ordre de l'icone.
+	gboolean bForceUpdate = FALSE;
 	if (icon2 != NULL)
 	{
 		Icon *pNextIcon = cairo_dock_get_next_icon (pDock->icons, icon2);
+		if (pNextIcon != NULL && fabs (pNextIcon->fOrder - icon2->fOrder) < 1e-3)
+		{
+			bForceUpdate = TRUE;
+		}
 		if (pNextIcon == NULL || cairo_dock_get_icon_order (pNextIcon) != cairo_dock_get_icon_order (icon2))
 			icon1->fOrder = icon2->fOrder + 1;
 		else
 			icon1->fOrder = (pNextIcon->fOrder - icon2->fOrder > 1 ? icon2->fOrder + 1 : (pNextIcon->fOrder + icon2->fOrder) / 2);
-		
-		if (fabs (icon2->fOrder - icon1->fOrder) < 1e-3)
-		{
-			cairo_dock_normalize_icons_order (pDock->icons, icon1->iType);
-		}
 	}
 	else
 	{
-		Icon *pFirstIcon = cairo_dock_get_first_icon_of_type (pDock->icons, icon1->iType);
+		Icon *pFirstIcon = cairo_dock_get_first_icon_of_order (pDock->icons, icon1->iType);
 		if (pFirstIcon != NULL)
 			icon1->fOrder = pFirstIcon->fOrder - 1;
 		else
 			icon1->fOrder = 1;
 	}
-
+	//g_print ("icon1->fOrder:%.2f\n", icon1->fOrder);
+	
 	//\_________________ On change l'ordre dans le fichier du lanceur 1.
 	if ((CAIRO_DOCK_IS_LAUNCHER (icon1) || CAIRO_DOCK_IS_SEPARATOR (icon1)) && icon1->acDesktopFileName != NULL)
 	{
-		GError *erreur = NULL;
 		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon1->acDesktopFileName);
-		GKeyFile* pKeyFile = g_key_file_new();
-		g_key_file_load_from_file (pKeyFile, cDesktopFilePath, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("%s", erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-		}
-		else
-		{
-			g_key_file_set_double (pKeyFile, "Desktop Entry", "Order", icon1->fOrder);
-			cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
-			g_key_file_free (pKeyFile);
-			g_free (cDesktopFilePath);
-		}
+		cairo_dock_update_conf_file (cDesktopFilePath,
+			G_TYPE_DOUBLE, "Desktop Entry", "Order", icon1->fOrder,
+			G_TYPE_INVALID);
+		g_free (cDesktopFilePath);
 	}
+	else if (CAIRO_DOCK_IS_APPLET (icon1))
+		cairo_dock_update_module_instance_order (icon1->pModuleInstance, icon1->fOrder);
 
 	//\_________________ On change sa place dans la liste.
 	pDock->pFirstDrawnElement = NULL;
@@ -591,10 +606,9 @@ void cairo_dock_move_icon_after_icon (CairoDock *pDock, Icon *icon1, Icon *icon2
 
 	//\_________________ On recalcule la largeur max, qui peut avoir ete influencee par le changement d'ordre.
 	cairo_dock_update_dock_size (pDock);
-
-	//\_________________ On prend en compte le changement de position pour les applets.
-	if (CAIRO_DOCK_IS_APPLET (icon1))
-		cairo_dock_update_module_instance_order (icon1->pModuleInstance, icon1->fOrder);
+	
+	if (bForceUpdate)
+		cairo_dock_normalize_icons_order (pDock->icons, icon1->iType);
 }
 
 
@@ -696,14 +710,15 @@ gboolean cairo_dock_detach_icon_from_dock (Icon *icon, CairoDock *pDock, gboolea
 		Icon * pSeparatorIcon = NULL;
 		if (! CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (icon))
 		{
-			Icon *pSameTypeIcon = cairo_dock_get_first_icon_of_type (pDock->icons, icon->iType);
+			Icon *pSameTypeIcon = cairo_dock_get_first_icon_of_order (pDock->icons, icon->iType);
 			if (pSameTypeIcon == NULL)
 			{
 				int iOrder = cairo_dock_get_icon_order (icon);
+				//g_print ("iOrder : %d\n", iOrder);
 				if (iOrder > 1)  // attention : iType - 1 > 0 si iType = 0, car c'est un unsigned int !
-					pSeparatorIcon = cairo_dock_get_first_icon_of_type (pDock->icons, iOrder - 1);
-				else if (iOrder + 1 < CAIRO_DOCK_NB_TYPES)
-					pSeparatorIcon = cairo_dock_get_first_icon_of_type (pDock->icons, iOrder + 1);
+					pSeparatorIcon = cairo_dock_get_first_icon_of_order (pDock->icons, iOrder - 1);
+				if (iOrder + 1 < CAIRO_DOCK_NB_TYPES && pSeparatorIcon == NULL)
+					pSeparatorIcon = cairo_dock_get_first_icon_of_order (pDock->icons, iOrder + 1);
 
 				if (pSeparatorIcon != NULL)
 				{
@@ -878,6 +893,7 @@ Icon *cairo_dock_foreach_icons_of_type (GList *pIconList, CairoDockIconType iTyp
 
 void cairo_dock_remove_all_separators (CairoDock *pDock)
 {
+	//g_print ("%s ()\n", __func__);
 	Icon *icon;
 	GList *ic;
 	if (pDock->icons == NULL)
@@ -892,6 +908,7 @@ void cairo_dock_remove_all_separators (CairoDock *pDock)
 		icon = ic->next->data;  // on ne peut pas enlever l'element courant, sinon on perd 'ic'.
 		if (CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (icon))
 		{
+			//g_print ("un separateur en moins (apres %s)\n", ((Icon*)ic->data)->acName);
 			cairo_dock_remove_one_icon_from_dock (pDock, icon);
 			cairo_dock_free_icon (icon);
 		}
@@ -900,11 +917,22 @@ void cairo_dock_remove_all_separators (CairoDock *pDock)
 			ic = ic->next;
 		}
 	} while (TRUE);
+	
+	if (pDock->icons != NULL)  // et oui il peut y'avoir un separateur aussi au debut, apres qu'on ait enlever un groupe d'icones entier ! c'est vicieux n'est-ce pas ? ^_^
+	{
+		icon = pDock->icons->data;
+		if (CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (icon))
+		{
+			//g_print ("un separateur en moins (au debut)\n");
+			cairo_dock_remove_one_icon_from_dock (pDock, icon);
+			cairo_dock_free_icon (icon);
+		}
+	}
 }
 
-
 void cairo_dock_insert_separators_in_dock (CairoDock *pDock)
 {
+	//g_print ("%s ()\n", __func__);
 	Icon *icon, *next_icon;
 	GList *ic;
 	for (ic = pDock->icons; ic != NULL; ic = ic->next)
@@ -915,9 +943,10 @@ void cairo_dock_insert_separators_in_dock (CairoDock *pDock)
 			if (ic->next != NULL)
 			{
 				next_icon = ic->next->data;
-				if (! CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (icon) && icon->iType != next_icon->iType)
+				if (! CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (next_icon) && abs (cairo_dock_get_icon_order (icon) - cairo_dock_get_icon_order (next_icon)) > 1)  // icon->iType != next_icon->iType
 				{
 					int iSeparatorType = g_tIconTypeOrder[next_icon->iType] - 1;
+					//g_print ("un separateur entre %s et %s, dans le groupe %d (=%d)\n", icon->acName, next_icon->acName, iSeparatorType, g_tIconTypeOrder[iSeparatorType]);
 					cairo_t *pCairoContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDock));
 					Icon *pSeparator = cairo_dock_create_separator_icon (pCairoContext, iSeparatorType, pDock, ! CAIRO_DOCK_APPLY_RATIO);
 					cairo_destroy (pCairoContext);
@@ -930,26 +959,6 @@ void cairo_dock_insert_separators_in_dock (CairoDock *pDock)
 }
 
 
-void cairo_dock_insert_separator_between_launchers_and_applis (CairoDock *pDock)
-{
-	Icon *pFirstLauncher = cairo_dock_get_first_icon_of_type (pDock->icons, CAIRO_DOCK_LAUNCHER);
-	Icon *pFirstAppli = cairo_dock_get_first_icon_of_type (pDock->icons, CAIRO_DOCK_APPLI);
-
-	if (pFirstLauncher != NULL && pFirstAppli != NULL)
-	{
-		int iSeparatorType = MIN (g_tIconTypeOrder[CAIRO_DOCK_LAUNCHER], g_tIconTypeOrder[CAIRO_DOCK_APPLI]) + 1;
-		if (cairo_dock_get_first_icon_of_type (pDock->icons, iSeparatorType) == NULL)
-		{
-			cairo_t *pCairoContext = cairo_dock_create_context_from_window (CAIRO_CONTAINER (pDock));
-			Icon *pSeparator = cairo_dock_create_separator_icon (pCairoContext, iSeparatorType, pDock, ! CAIRO_DOCK_APPLY_RATIO);
-			cairo_destroy (pCairoContext);
-
-			cairo_dock_insert_icon_in_dock (pSeparator, pDock, !CAIRO_DOCK_UPDATE_DOCK_SIZE, ! CAIRO_DOCK_ANIMATE_ICON, CAIRO_DOCK_APPLY_RATIO, ! CAIRO_DOCK_INSERT_SEPARATOR);
-		}
-	}
-}
-
-
 GList *cairo_dock_calculate_icons_positions_at_rest_linear (GList *pIconList, double fFlatDockWidth, int iXOffset)
 {
 	//g_print ("%s (%d, +%d)\n", __func__, fFlatDockWidth, iXOffset);
@@ -1040,20 +1049,6 @@ Icon * cairo_dock_calculate_wave_with_position_linear (GList *pIconList, GList *
 			else
 				icon->fScale *= (1 + icon->fPersonnalScale);
 		}
-// 		if (icon->fPersonnalScale > 0 && iWidth > 0)
-// 		{
-// 			icon->fPersonnalScale *= .85;
-// 			icon->fScale *= icon->fPersonnalScale;
-// 			if (icon->fPersonnalScale < 0.05)
-// 				icon->fPersonnalScale = 0.05;
-// 		}
-// 		else if (icon->fPersonnalScale < 0 && iWidth > 0)
-// 		{
-// 			icon->fPersonnalScale *= .85;
-// 			icon->fScale *= (1 + icon->fPersonnalScale);
-// 			if (icon->fPersonnalScale > -0.05)
-// 				icon->fPersonnalScale = -0.05;
-// 		}
 		icon->fY = (bDirectionUp ? iHeight - g_iDockLineWidth - g_iFrameMargin - icon->fScale * icon->fHeight : g_iDockLineWidth + g_iFrameMargin);
 		
 		//\_______________ Si on avait deja defini l'icone pointee, on peut placer l'icone courante par rapport a la precedente.
