@@ -30,6 +30,7 @@ Written by Fabrice Rey (for any bug report, please mail me to fabounet@users.ber
 
 typedef struct _CairoDockRenderer CairoDockRenderer;
 typedef struct _CairoDeskletRenderer CairoDeskletRenderer;
+typedef struct _CairoDeskletDecoration CairoDeskletDecoration;
 typedef struct _CairoDialogRenderer CairoDialogRenderer;
 
 typedef struct _Icon Icon;
@@ -179,9 +180,13 @@ struct _CairoDock {
 	gdouble fRatio;
 
 	gint iMaxLabelWidth;
+	gint iMinLeftMargin;
+	gint iMinRightMargin;
+	gint iMaxLeftMargin;
+	gint iMaxRightMargin;
+	gint iLeftMargin;
 	gint iRightMargin;
-	gint iTopMargin;
-
+	
 	//\_______________ Les parametres lies a une animation du dock.
 	/// pour faire defiler les icones avec la molette.
 	gint iScrollOffset;
@@ -378,6 +383,9 @@ struct _CairoDockMinimalAppletConfig {
 	gboolean bKeepAbove;
 	gboolean bOnWidgetLayer;
 	gboolean bPositionLocked;
+	gint iRotation;
+	gchar *cDecorationTheme;
+	CairoDeskletDecoration *pUserDecoration;
 };
 
 
@@ -616,6 +624,8 @@ struct _Icon {
 	gboolean bIsFullScreen;
 	/// TRUE ssi la fenetre est en mode maximisee.
 	gboolean bIsMaximized;
+	/// TRUE ssi la fenetre demande l'attention ou est en mode urgente.
+	gboolean bIsDemandingAttention;
 	//\____________ Pour les modules.
 	/// Instance de module que represente l'icone.
 	CairoDockModuleInstance *pModuleInstance;
@@ -701,6 +711,7 @@ struct _CairoDockVFSBackend {
 	CairoDockFMGetTrashFunc 		get_trash_path;
 	CairoDockFMGetDesktopFunc 	get_desktop_path;
 	CairoDockFMUserActionFunc		logout;
+	CairoDockFMUserActionFunc		shutdown;
 	CairoDockFMUserActionFunc		setup_time;
 };
 
@@ -780,8 +791,45 @@ struct _CairoDesklet {
 	gint iDesiredWidth, iDesiredHeight;
 	/// taille connue par l'applet associee.
 	gint iKnownWidth, iKnownHeight;
+	/// les decorations.
+	gchar *cDecorationTheme;
+	CairoDeskletDecoration *pUserDecoration;
+	gint iLeftSurfaceOffset;
+        gint iTopSurfaceOffset;
+        gint iRightSurfaceOffset;
+        gint iBottomSurfaceOffset;
+        cairo_surface_t *pBackGroundSurface;
+        cairo_surface_t *pForeGroundSurface;
+        gdouble fImageWidth;
+        gdouble fImageHeight;
+	gdouble fBackGroundAlpha;
+        gdouble fForeGroundAlpha;
+	/// rotation.
+	gdouble fRotation;
+	gboolean rotating;
+	/// rattachement au dock.
+	gboolean retaching;
+	/// date du clic.
+	guint time;
 };
 
+typedef enum {
+	CAIRO_DOCK_FILL_SPACE 		= 0,
+	CAIRO_DOCK_KEEP_RATIO 		= 1<<0,
+	CAIRO_DOCK_DONT_ZOOM_IN 	= 1<<1
+	} CairoDockLoadImageModifier;
+
+struct _CairoDeskletDecoration {
+	gchar *cBackGroundImagePath;
+	gchar *cForeGroundImagePath;
+	CairoDockLoadImageModifier iLoadingModifier;
+	gdouble fBackGroundAlpha;
+        gdouble fForeGroundAlpha;
+	gint iLeftMargin;
+	gint iTopMargin;
+	gint iRightMargin;
+	gint iBottomMargin;
+	};
 
 #define CAIRO_DOCK_FM_VFS_ROOT "_vfsroot_"
 #define CAIRO_DOCK_FM_NETWORK "_network_"
@@ -856,7 +904,7 @@ struct _CairoFlyingContainer {
 };
 
 /// Nom du repertoire de travail de cairo-dock.
-#define CAIRO_DOCK_DATA_DIR ".cairo-dock"
+#define CAIRO_DOCK_DATA_DIR "cairo-dock"
 /// Nom du repertoire des themes utilisateur.
 #define CAIRO_DOCK_THEMES_DIR "themes"
 /// Nom du repertoire des extras utilisateur/themes (jauges, clock, etc).
@@ -865,8 +913,12 @@ struct _CairoFlyingContainer {
 #define CAIRO_DOCK_GAUGES_DIR "gauges"
 /// Nom du repertoire du theme courant.
 #define CAIRO_DOCK_CURRENT_THEME_NAME "current_theme"
-/// Nom du repertoire des lanceurs et de leurs icones.
+/// Nom du repertoire des lanceurs.
 #define CAIRO_DOCK_LAUNCHERS_DIR "launchers"
+/// Nom du repertoire des icones locales.
+#define CAIRO_DOCK_LOCAL_ICONS_DIR "icons"
+/// Mot cle representant le repertoire local des icones.
+#define CAIRO_DOCK_LOCAL_THEME_KEYWORD "_LocalTheme_"
 /// Nom du dock principal (le 1er cree).
 #define CAIRO_DOCK_MAIN_DOCK_NAME "_MainDock_"
 /// Nom de la vue par defaut.
@@ -907,7 +959,7 @@ typedef enum {
 	CAIRO_DOCK_GNOME,
 	CAIRO_DOCK_KDE,
 	CAIRO_DOCK_XFCE,
-	CAIRO_DOCK_NO_DESKTOP
+	CAIRO_DOCK_NB_DESKTOPS
 	} CairoDockDesktopEnv;
 
 typedef enum {
@@ -925,10 +977,4 @@ typedef enum {
 	CAIRO_DOCK_NB_NEW_LAUNCHER_TYPE
 	} CairoDockNewLauncherType;
 
-typedef enum {
-	CAIRO_DOCK_FILL_SPACE 		= 0,
-	CAIRO_DOCK_KEEP_RATIO 		= 1<<0,
-	CAIRO_DOCK_DONT_ZOOM_IN 	= 1<<1
-	} CairoDockLoadImageModifier;
-
 #endif
