@@ -204,13 +204,11 @@ double g_fDialogColor[4];
 int g_iDialogIconSize;
 CairoDockLabelDescription g_dialogTextDescription;
 
-double g_fDeskletColor[4];
-double g_fDeskletColorInside[4];
-
 gchar *g_cRaiseDockShortcut = NULL;
 
 gboolean g_bKeepAbove = FALSE;
 gboolean g_bPopUp = FALSE;
+gboolean g_bPopUpOnScreenBorder;
 gboolean g_bSkipPager = TRUE;
 gboolean g_bSkipTaskbar = TRUE;
 gboolean g_bSticky = TRUE;
@@ -243,7 +241,10 @@ gboolean g_bUseFakeTransparency = FALSE;
 
 gboolean g_bDisplayDropEmblem = FALSE; // indicateur de drop
 gchar *g_cThemeServerAdress = NULL;
-gboolean g_bTesting = FALSE;
+gboolean g_bEasterEggs = FALSE;
+gboolean g_bLocked = FALSE;
+
+gchar *g_cDeskletDecorationsName = NULL;
 
 static gchar *cLaunchCommand = NULL;
 
@@ -308,7 +309,7 @@ int main (int argc, char** argv)
 	GError *erreur = NULL;
 	
 	//\___________________ On recupere quelques options.
-	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSkipPager = FALSE, bNoSkipTaskbar = FALSE, bNoSticky = FALSE, bToolBarHint = FALSE, bNormalHint = FALSE, bCappuccino = FALSE, bExpresso = FALSE, bCafeLatte = FALSE, bPrintVersion = FALSE;
+	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSkipPager = FALSE, bNoSkipTaskbar = FALSE, bNoSticky = FALSE, bToolBarHint = FALSE, bNormalHint = FALSE, bCappuccino = FALSE, bExpresso = FALSE, bCafeLatte = FALSE, bPrintVersion = FALSE, bTesting = FALSE;
 	gchar *cEnvironment = NULL, *cUserDefinedDataDir = NULL, *cVerbosity = 0, *cUserDefinedModuleDir = NULL;
 	GOptionEntry TableDesOptions[] =
 	{
@@ -351,7 +352,7 @@ int main (int argc, char** argv)
 		{"capuccino", 'C', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bCappuccino,
 			"Cairo-Dock makes anything, including coffee !", NULL},
-		{"expresso", 'E', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+		{"expresso", 'X', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bExpresso,
 			"Cairo-Dock makes anything, including coffee !", NULL},
 		{"cafe-latte", 'L', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
@@ -363,15 +364,18 @@ int main (int argc, char** argv)
 		{"modules-dir", 'M', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&cUserDefinedModuleDir,
 			"ask the dock to load additionnal modules contained in this directory (though it is unsafe for your dock to load unnofficial modules).", NULL},
-		{"fake-transparency", 'F', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&g_bUseFakeTransparency,
-			"emulate composition with fake transparency. Only use this if you don't run a compositor like Compiz, xcompmgr, etc and have a black background around your dock.", NULL},
 		{"testing", 'T', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&g_bTesting,
-			"for debugging purpose only. The crash manager will not be started, and some unstable options may be activated.", NULL},
+			&bTesting,
+			"for debugging purpose only. The crash manager will not be started to hunt down the bugs.", NULL},
+		{"easter-eggs", 'E', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&g_bEasterEggs,
+			"for debugging purpose only. Some hidden and still unstable options will be activated.", NULL},
 		{"server", 'S', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&g_cThemeServerAdress,
 			"adress of a server containing additional themes. This will overwrite the default server adress.", NULL},
+		{"locked", 'k', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&g_bLocked,
+			"lock the dock so that any modification is impossible for users.", NULL},
 		{NULL}
 	};
 
@@ -399,6 +403,9 @@ int main (int argc, char** argv)
 		return 0;
 	}
 	
+	if (g_bLocked)
+		g_print ("Cairo-Dock will be locked.\n");
+	
 	_cairo_dock_set_verbosity(cVerbosity);
 	g_free (cVerbosity);
 
@@ -419,7 +426,7 @@ int main (int argc, char** argv)
 		else if (strcmp (cEnvironment, "xfce") == 0)
 			g_iDesktopEnv = CAIRO_DOCK_XFCE;
 		else if (strcmp (cEnvironment, "none") == 0)
-			g_iDesktopEnv = CAIRO_DOCK_NO_DESKTOP;
+			g_iDesktopEnv = CAIRO_DOCK_UNKNOWN_ENV;
 		else
 			cd_warning ("Attention : unknown environnment '%s'", cEnvironment);
 		g_free (cEnvironment);
@@ -456,11 +463,52 @@ int main (int argc, char** argv)
 	textdomain (CAIRO_DOCK_GETTEXT_PACKAGE);
 
 	//\___________________ On teste l'existence du repertoire des donnees .cairo-dock.
-	g_cCairoDockDataDir = (cUserDefinedDataDir != NULL ? cUserDefinedDataDir : g_strdup_printf ("%s/%s", getenv("HOME"), CAIRO_DOCK_DATA_DIR));
-	if (! g_file_test (g_cCairoDockDataDir, G_FILE_TEST_IS_DIR))
+	if (cUserDefinedDataDir != NULL)
 	{
-		if (g_mkdir (g_cCairoDockDataDir, 7*8*8+7*8+5) != 0)
-			cd_warning ("Attention : couldn't create directory %s", g_cCairoDockDataDir);
+		g_cCairoDockDataDir = cUserDefinedDataDir;
+		cUserDefinedDataDir = NULL;
+		if (! g_file_test (g_cCairoDockDataDir, G_FILE_TEST_IS_DIR))
+		{
+			if (g_mkdir (g_cCairoDockDataDir, 7*8*8+7*8+5) != 0)
+				cd_warning ("Attention : couldn't create directory %s", g_cCairoDockDataDir);
+		}
+	}
+	else
+	{
+		g_cCairoDockDataDir = g_strdup_printf ("%s/.config/%s", getenv("HOME"), CAIRO_DOCK_DATA_DIR);
+		if (! g_file_test (g_cCairoDockDataDir, G_FILE_TEST_IS_DIR))
+		{
+			gchar *cOldDataDir = g_strdup_printf ("%s/.cairo-dock", getenv("HOME"));
+			if (g_file_test (cOldDataDir, G_FILE_TEST_IS_DIR))  // l'ancien rep existe, on le deplace.
+			{
+				cd_warning ("Cairo-Dock's data dir is now located in ~/.config, it will be moved there");
+				gchar *cCommand = g_strdup_printf ("mkdir '%s/.config' > /dev/null", getenv("HOME"));
+				cd_message ("%s", cCommand);
+				system (cCommand);
+				g_free (cCommand);
+					
+				cCommand = g_strdup_printf ("mv '%s' '%s'", cOldDataDir, g_cCairoDockDataDir);
+				cd_message ("%s", cCommand);
+				system (cCommand);
+				g_free (cCommand);
+				
+				cCommand = g_strdup_printf ("sed -i \"s/~\\/.cairo-dock/~\\/.config\\/%s/g\" '%s/%s/%s'", CAIRO_DOCK_DATA_DIR, g_cCairoDockDataDir, CAIRO_DOCK_CURRENT_THEME_NAME, CAIRO_DOCK_CONF_FILE);
+				cd_message ("%s", cCommand);
+				system (cCommand);
+				g_free (cCommand);
+				
+				cCommand = g_strdup_printf ("sed -i \"/default icon directory/ { s/~\\/.config\\/%s\\/%s\\/icons/%s/g }\" '%s/%s'", CAIRO_DOCK_DATA_DIR, CAIRO_DOCK_CURRENT_THEME_NAME, CAIRO_DOCK_LOCAL_THEME_KEYWORD, g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE);
+				cd_message ("%s", cCommand);
+				system (cCommand);
+				g_free (cCommand);
+			}
+			else
+			{
+				if (g_mkdir (g_cCairoDockDataDir, 7*8*8+7*8+5) != 0)
+					cd_warning ("Attention : couldn't create directory %s", g_cCairoDockDataDir);
+			}
+			g_free (cOldDataDir);
+		}
 	}
 	gchar *cThemesDir = g_strdup_printf ("%s/%s", g_cCairoDockDataDir, CAIRO_DOCK_THEMES_DIR);
 	if (! g_file_test (cThemesDir, G_FILE_TEST_IS_DIR))
@@ -488,6 +536,31 @@ int main (int argc, char** argv)
 		if (g_mkdir (g_cCurrentLaunchersPath, 7*8*8+7*8+5) != 0)
 			cd_warning ("Attention : couldn't create directory %s", g_cCurrentLaunchersPath);
 	}
+	gchar *cLocalIconsPath = g_strdup_printf ("%s/%s", g_cCurrentThemePath, CAIRO_DOCK_LOCAL_ICONS_DIR);
+	if (! g_file_test (cLocalIconsPath, G_FILE_TEST_IS_DIR))
+	{
+		if (g_mkdir (cLocalIconsPath, 7*8*8+7*8+5) != 0)
+			cd_warning ("Attention : couldn't create directory %s", cLocalIconsPath);
+		else
+		{
+			cd_warning ("Cairo-Dock's local icons are now located in the 'icons' folder, they will be moved there");
+			gchar *cCommand = g_strdup_printf ("cd '%s' && mv *.svg *.png *.xpm *.jpg *.bmp *.gif '%s' > /dev/null", g_cCurrentLaunchersPath, cLocalIconsPath);
+			cd_message ("%s", cCommand);
+			system (cCommand);
+			g_free (cCommand);
+			
+			cCommand = g_strdup_printf ("sed -i \"s/_ThemeDirectory_/%s/g\" '%s/%s'", CAIRO_DOCK_LOCAL_THEME_KEYWORD, g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE);
+			cd_message ("%s", cCommand);
+			system (cCommand);
+			g_free (cCommand);
+			
+			cCommand = g_strdup_printf ("sed -i \"/default icon directory/ { s/~\\/.config\\/%s\\/%s\\/icons/%s/g }\" '%s/%s'", CAIRO_DOCK_DATA_DIR, CAIRO_DOCK_CURRENT_THEME_NAME, CAIRO_DOCK_LOCAL_THEME_KEYWORD, g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE);
+			cd_message ("%s", cCommand);
+			system (cCommand);
+			g_free (cCommand);
+		}
+	}
+	g_free (cLocalIconsPath);
 	
 	//\___________________ On initialise les numeros de version.
 	cairo_dock_get_version_from_string (CAIRO_DOCK_VERSION, &g_iMajorVersion, &g_iMinorVersion, &g_iMicroVersion);
@@ -534,7 +607,7 @@ int main (int argc, char** argv)
 	cairo_dock_register_notification (CAIRO_DOCK_REMOVE_ICON, (CairoDockNotificationFunc) cairo_dock_notification_remove_icon, CAIRO_DOCK_RUN_AFTER, NULL);
 	
 	//\___________________ On initialise la gestion des crash.
-	if (! g_bTesting)
+	if (! bTesting)
 		_cairo_dock_set_signal_interception ();
 	
 	//\___________________ On charge le dernier theme ou on demande a l'utilisateur d'en choisir un.
@@ -543,7 +616,7 @@ int main (int argc, char** argv)
 	
 	gboolean config_ok;
 	if (bMaintenance)
-		config_ok = cairo_dock_edit_conf_file (NULL, g_cConfFile, _("< Maintenance mode >"), 800, 600, 0, NULL, NULL, NULL, NULL, NULL);
+		config_ok = cairo_dock_edit_conf_file (NULL, g_cConfFile, _("< Maintenance mode >"), 800, 600, 0, NULL, NULL, NULL, NULL, CAIRO_DOCK_GETTEXT_PACKAGE);
 	
 	if (! g_file_test (g_cConfFile, G_FILE_TEST_EXISTS) || bSafeMode)
 	{
@@ -636,8 +709,9 @@ int main (int argc, char** argv)
 	//const gchar *cSillyMessage = "J-2 avant la 1.5, la tension monte !";
 	//const gchar *cSillyMessage = "Cairo-Dock : sans danger si l'on se conforme au mode d'emploi.";
 	//const gchar *cSillyMessage = "Nochka, ton home a disparu !";
-	const gchar *cSillyMessage = "La nouvelle sauce Cairo-Dock rehaussera le goût de tous vos plats !";
-	const gchar *cNumSilllyMessage = "18";
+	//const gchar *cSillyMessage = "La nouvelle sauce Cairo-Dock rehaussera le goût de tous vos plats !";
+	const gchar *cSillyMessage = "Avec Cairo-Dock c'est vous qui avez la plus grosse (barre de lancement) !";
+	const gchar *cNumSilllyMessage = "19";
 	gboolean bWriteSillyMessage;
 	if (! g_file_test (cSillyMessageFilePath, G_FILE_TEST_EXISTS))
 	{
@@ -686,7 +760,7 @@ int main (int argc, char** argv)
 		cd_message (" ==> %.2f\n", fAnswer);*/
 	}
 	
-	if (! g_bTesting)
+	if (! bTesting)
 		g_timeout_add_seconds (5, _cairo_dock_successful_launch, NULL);
 	
 	gtk_main ();
